@@ -1,5 +1,7 @@
 from unittest import TestCase
+
 import pandas as pd
+
 from cbcvalidator.main import Validate, ValueOutOfRange
 
 
@@ -26,7 +28,6 @@ class TestValidate(TestCase):
         golden = 5
         self.assertEqual(golden, test)
 
-
         data = {'a': [1, 2, 3, 4, 5, 6, 7, 8],
                 'b': ['abcdefg', 'abcdefghijkl', 'a', 'b', 'c', 'd', 'ef', 'ghi']}
         df = pd.DataFrame(data)
@@ -45,7 +46,6 @@ class TestValidate(TestCase):
         test = pd.isnull(df.loc[2, 'b'])
         self.assertTrue(test)
 
-
         data = {'a': [1, 2, 3, 4, 5, 6, 7, 8],
                 'b': ['abcdefg', 'abcdefghijkl', 'a', 'b', 'c', 'd', 'ef', 'ghi']}
         df = pd.DataFrame(data)
@@ -76,4 +76,31 @@ class TestValidate(TestCase):
         ]
 
         df, msg = v.validate(df, val_dict)
-        # So long as this doesn't raise an error it's fine.
\ No newline at end of file
+        # So long as this doesn't raise an error it's fine.
+
+        # Test what happens when a numeric column is processed as a string. This should do nothing, but print a
+        # warning.
+        data = {'a': [1, 2, 3, 4, 5, 6, 7, 8],
+                'b': ['abcdefg', 'abcdefghijkl', 'a', 'b', 'c', 'd', 'ef', 'ghi']}
+        df = pd.DataFrame(data)
+        val_dict = [
+            {'col': 'a', 'min_len': 2, 'max_len': 7, 'action': 'trim'}
+        ]
+
+        df, msg = v.validate(df, val_dict)
+        test = df.loc[0, 'a']
+        self.assertEqual(1, test)
+
+        # Test for a missing column
+        data = {'a': [1, 2, 3, 4, 5, 6, 7, 8],
+                'b': ['abcdefg', 'abcdefghijkl', 'a', 'b', 'c', 'd', 'ef', 'ghi']}
+        df = pd.DataFrame(data)
+        val_dict = [
+            {'col': 'not_a_col_name', 'min_len': 2, 'max_len': 7, 'action': 'trim'}
+        ]
+
+        df, msg = v.validate(df, val_dict)
+        test = df.loc[0, 'a']
+        self.assertEqual(1, test)
+
+
